ctsu = r"""

\begin{table}
  \centering
  \begin{tabular}{ll}
    \hline
    \textbf{Titolo dello studio} & \\
    \textbf{Acronimo} & \\
    \textbf{Versione protocollo} & 1.0 \\
    \textbf{Data rilascio protocollo} &  \\
    \textbf{Codici registrazione} & se applicabili (es ClinicalTrials.gov: NCT01066572) \\
    \hline
    \textbf{Promotore} & Azienda farmaceutica, gruppo cooperativo, ente non profit che promuove lo studio. Nel caso di studi spontanei locali inserire Azienda USL - IRCCS di Reggio Emilia.\\
    \textbf{Proponente} &  Nome e qualifica delle persone autorizzate a firmare il protocollo e gli emendamenti a nome del promotore. Data e firma, per accettazione.\\
    \textbf{Partecipanti} &  Sperimentatori responsabili della conduzione dello studio con relativa strutture di appartenenza  ( es.: strutture specialistiche e laboratori ...).\\
    \textbf{Recapiti randomizzazione} &  \\
    \textbf{Referenti farmacovigilanza} &  \\
    \textbf{Referente statistico} &  \\
    \textbf{Referente monitoraggio} &  \\
  \end{tabular}
\end{table}


 \\
 \\
 \\

\textbf{UNA VOLTA COMPLETATA LA SCRITTURA INSERIRE QUI IL SOMMARIO
  (eventualmente in pagina a sé stante)}

 \\
 \\
 \\


% ---------------------------------------------------------
\section{Background}
Fornire una sintesi sulla problematica affrontata (es la patologia),
sulla attuale pratica clinica (es da linee guida), e sulle questioni
attualmente aperte (con riferimento aggiornato alla letteratura
esistente).

% ---------------------------------------------------------
\section{Lo studio}

\subsection{Ipotesi e razionale}
L'intento dello studio deve essere definito in modo chiaro e
preciso. Specificare qui la/le ipotesi da verificare e le ragioni che
giustificano tale proposta (es non precedentemente/sufficientemente
indagate in letteratura?).

\subsection{Disegno dello studio}
Sintetizzare gli aspetti salienti dello studio. Ad esempio la
tipologia (sperimentale/osservazionale); mono/multicentricità;
retrospettivo/prospettico; lo tipologia/scopo dell'indagine
(descrittivo, diagnostico, di trattamento, prognostico ecc).\\
Nel caso di studi su un trattamento, il metodo di allocazione dello
stesso (randomizzata/non randomizzata); la tipologia di trattamento
(farmacologico, dispositivo, altro); la fase (I-II-III-IV); gli
aspetti di mascheramento (in aperto, cieco, doppio cieco, triplo
cieco); ecc.\\
Infine, qualora presenti, quali studi ancillari e/o sotto-studi sono
previsti.

\section{Popolazione}
Descrivere qui la tipologia di contesto (es ospedaliero/territoriale)
dove si realizzerà lo studio e dove avverrà l'arruolamento (o
comunque, anche nel caso degli studi retrospettivi, il contesto a cui
si riferiranno i i risultati dello studio).

\subsection{Criteri di inclusione}
Inserirli in forma schematica (elenchi puntati/numerati) e
dettagliati.

\subsection{Criteri di esclusione}
Sempre in forma schematica (elenchi puntati/numerati) e dettagliati;
non serve introdurre negazioni dei criteri di inclusione (ad esempio
se un criterio di inclusione è età >= 18 qui non serve specificare età
< 18).


\subsection{Modalità di reclutamento dei pazienti}
INSERIRE QUALCHE SUGGERIMENTO GENERICO / SEMPLICE QUI su cosa inserire
qui?

\subsection{Allocazione al trattamento (randomizzazione)}
Nel caso di studi su trattamento, descrivere il processo di
assegnazione di ciascun paziente al trattamento (es randomizzazione o
altro).


\section{Aspetti organizzativi e logistici}


\subsection{Fasi e durata dello studio}
Sintetizzare qui, anche mediante esemplificazioni grafiche (es
flow-chart, tempogrammi, diagrammi GANTT) la pianificazione dello
studio del suo complesso e il susseguirsi delle varie sue fasi: ad
esempio arruolamento, trattamento, follow up (FPFV-LPLV: da first
patient first visit a last patient last visit) e raccolta dati, analisi).\\
A valle di questo, fornire una stima della durata complessiva
prevista.


\subsection{Programma di trattamento}
Dosaggi e schedule, durata, tossicità attese, modifiche al
trattamento.

\subsection{Valutazione outcomes ed effetti collaterali}
Tempistiche e criteri/standard adottati (es RECIST) per la valutazione
degli outcome e degli effetti avversi (se applicabile).

\section{Interruzione dello studio}
Inserire le norme di interruzione per lo studio e criteri per il
ritiro dei pazienti dallo stesso.

% ---------------------------------------------------------
\section{Obiettivi}
Riportare in questa sezione le ipotesi da sottoporre a verifica,
scritte in maniera schematica e gerarchica (un obiettivo primario e
alcuni obiettivi secondari).


\paragraph{Primario}
Ad esempio: Obiettivo primario è valutare l'effetto del trattamento
sulla sopravvivenza dei pazienti randomizzati.

\paragraph{Secondari}


\section{Aspetti statistici}

\subsection{Outcome}
Riportare in questa sezione le variabili che verranno utilizzate per
valutare le ipotesi. Come sono definite e quando vengono misurate.\\
Ad esempio: per la valutazione della sopravvivenza si utilizzerà la
Progression Free Survival, definita come tempo tra la randomizzazione
e la prima tra data di ripresa o decesso.

\paragraph{Primario}


\paragraph{Secondari}

\subsection{Analisi}
Questa sezione è a cura dell'Ufficio Studi Clinici e Statistica.

\paragraph{Primaria}

\paragraph{Secondarie}

\subsection{Ampiezza campionaria}
Questa sezione è a cura dell'Ufficio Studi Clinici e Statistica.

\section{Aspetti di data management}
Specificare quali strumenti saranno impiegati per la raccolta dei dati
(es Excel/Smarty). Qualora i dati derivino dall'estrazione a partire
da una/più fonte informativa/e già esistente/i (es cartella clinica
informatizzata, registri/database, etc) specificare la/e
fonte/i. Infine fare riferimento ad un documento allegato, per quanto
riguarda l'elenco delle variabili raccolte o la struttura della CRF.


\section{Aspetti etici e autorizzativi}
Specificare aspetti quali:
\begin{itemize}
\item considerazioni etiche e riferimenti normativi;
\item informazione sullo studio, modalità di raccolta del
  consenso allo studio ed al trattamento dati;
\item aspetti assicurativi;
\item accordi finanziari (trattati in documento separato);
\item accesso ai dati da parte di autorità regolatorie.
\end{itemize}

\section{Monitoraggio e QC}
Specificare aspetti quali:
\begin{itemize}
\item piano di monitoraggio proposto;
\item modalità di accesso ai dati e controlli di qualità.
\end{itemize}

\section{Sicurezza/Farmacovigilanza}
Modalità di rilevazione e segnalazione degli eventi, obblighi di
farmacovigilanza, SOP di riferimento.

\section{Responsabilità e politica di pubblicazione}
Criteri di pubblicazione (se non trattati in documento
separato). Proprietà dei dati e modalità di diffusione.

\section{Riferimenti bibliografici}
Inserire l'elenco della bibliografia citata nel documento.

\section{Appendici e allegati}
Eventuali documenti in allegato (es.: strumenti di valutazione,
questionari, scale, schede segnalazione eventi avversi seri, schede
raccolta dati, ecc)

"""

heap = r"""

\section{Administrative information}
This Health Economics Analysis Plan (HEAP) is written according to
\cite{thorn2021heap}.


\begin{table}
  \centering
  \begin{tabular}{ll}
    \hline
    \textbf{Title} &
                     Title that matches protocol and which includes the phrase ‘Health Economics
                     Analysis Plan'
                     % Health economics analysis plan for the [trial name]: a
                     % multi-centre randomised controlled trial to assess whether X
                     % improves the outcome of Y
    \\
    \textbf{Trial registration number} &
                                         Trial registration number and name of registry that
                                         uniquely identifies the clinical trial on a publicly
                                         accessible registry (and other relevant trial study numbers)
                                         % ISRCTNXXXXXXXX (ISRCTN
                                         % registry)
    \\
    \textbf{Source of funding} &
                                 Name of funders for trial and economic evaluation and funder(s)’ reference number(s)
                                 % National Institute for Health
                                 % Research, Health Technology
                                 % Assessment; Reference number –
                                 % XX/XX/XX
    \\
    \textbf{Purpose of HEAP} &
                               Brief statement of the purpose of the HEAP
                               % The purpose of this HEAP is to
                               % describe the analysis and reporting
                               % procedure intended for the economic
                               % analyses to be undertaken. The
                               % analysis plan is designed to ensure
                               % that there is no conflict with the
                               % protocol and associated statistical
                               % analysis plan and it should be read
                               % in conjunction with them.

    \\
    \textbf{Trial protocol version} &
                                      Trial protocol version number associated with this HEAP
                                      % This document has been written
                                      % based on information contained
                                      % in the trial protocol version
                                      % 4, dated 14 October 2019
    \\
    \textbf{Trial Statistical Analysis Plan (SAP) version} &
                                                             SAP version number associated with this HEAP
                                                             % SAP Version: 1.0, Date: 4 August 2019
    \\
    \textbf{Trial HEAP version} &
                                  Sequential number and date of this version
                                  % HEAP Version: 1.0, Date: 4 August 2019
    \\                          
    \textbf{HEAP revisions} &
                              Date, justification for revision and summary of changes to the HEAP. Specify the individual making any revisions/changes to the HEAP.
                              % The HEAP revision history can be
                              % presented in tabular format with the
                              % following column headings: Updated
                              % HEAP Version No; Protocol version;
                              % Section number changed; Description
                              % of, and reason for, change; Individual
                              % making the change (e.g. Dr [name] made
                              % the revision before any comparative
                              % analyses had been conducted); Date
                              % changed.
                              % Each row subsequently added to the
                              % table will indicate each HEAP revision
                              % change.
    \\
    \textbf{Roles and responsibilities} &
                                          Names, affiliations and roles of individuals who have significantly contributed to the HEAP
                                          % This HEAP was prepared by
                                          % Dr [name] (junior health
                                          % economist) and approved
                                          % by, Prof/Dr [name] (senior
                                          % health economist). The
                                          % trial health economist(s)
                                          % [name (s)] are responsible
                                          % for conducting and
                                          % reporting the economic
                                          % evaluation in accordance
                                          % with the HEAP.
    \\
    \textbf{Signature(s) of person(s) writing HEAP} &
                                                      Signature(s) of the person(s) writing the HEAP (and date)
    \\
    \textbf{Signature of senior health economist} &
                                                    Signature of senior health economist who is guarantor of the economic evaluation (and date)
    \\
    \textbf{Signature of Chief Investigator} &
                                               Signature of the Chief Investigator for the trial (and date)
    \\
    \hline
  \end{tabular}
\end{table}

\subsection*{Table  of contents}

List of HEAP contents with page numbers

\subsection*{Abbreviations/glossary of terms/definitions}

\begin{table}
  \centering
  \begin{tabular}{ll}
    \hline
    CEA & Cost effectiveness analysis \\
    CUA & Cost utility analysis \\
    QALY & quality-adjusted life year \\
    NHS & National Health Service \\
    \hline
  \end{tabular}
\end{table}



\section{Trial introduction \& background}

\subsection{Trial background and rationale}

Synopsis of trial background and rationale including a brief
description of research question and brief justification for
undertaking the trial

% Testing the effectiveness of new school-based educational
% interventions for children and young people with depression is a
% priority. The [trial name] is a pragmatic, parallel design, two arm,
% multicentre randomised controlled trial to determine whether a
% group-based CBT course is more effective than curriculum as usual
% for people who have had a diagnosis of depression in the past 24
% months.

\subsection{Aim(s) of the trial}

Clearly and briefly state the main aim(s) of the trial

% Briefly, the [trial name] RCT aims to inform primary care
% prescribing practice by investigating the severity and duration of
% depressive symptoms that are associated with a clinically
% significant response to sertraline compared to placebo, in people
% presenting to primary care with depression.


\subsection{Objectives and/or research hypotheses of the trial}

Describe specific trial objectives (primary and secondary) or trial
hypotheses

% Primary objective: to assess whether there is a clinically important
% difference in the impact of fatigue 26 weeks after baseline
% (i.e. starting the intervention) between patients participating in a
% cognitive-behavioural course delivered by the clinical team compared
% with patients receiving usual care. Secondary objectives: to compare
% differences between groups for secondary outcomes of fatigue
% severity, sleep, pain, disability, health service use, quality of
% life and cost-effectiveness for the NHS, patients and society.


\subsection{Trial population}

Describe the trial inclusion and exclusion criteria

% Inclusion criteria: GP patients with a diagnosis of severe mental
% illness. Raised total cholesterol above 5 or raised total
% cholesterol above 4 and one or more of the following risk factors:
% Current smoker, BMI>30kg/m2, diagnosis of diabetes and aged 30-75
% years old.  Exclusion criteria: Under acute psychiatric care.  Life
% expectancy of less than 6 months.  Pregnant at baseline.  Unable to
% give informed consent.


\subsection{Intervention(s) and comparator(s)}

Describe the intervention(s) and comparator(s)

% Intervention: Patients in the GP practices allocated to the
% intervention will be offered an enhanced cardiovascular disease risk
% reducing service over 6 months. The intervention will include one or
% more of the following elements: lifestyle advice, education on diet
% and exercise, behavioural techniques to encourage patients to make
% healthy lifestyle changes, signposting to smoking cessation or
% physical activity programmes.  Comparator: Treatment as usual.


\subsection{Trial design}

Briefly describe the trial design including type of trial such as
cluster, crossover, etc. Can also include details of power
calculation, sample size (including any separate calculations for
economic endpoints), randomisation and blinding.

% This is a non-blinded cluster RCT with GP practices being randomised
% to the intervention or treatment as usual on a 1:1 basis.
% Randomisation of GP practices will be carried out by an independent
% statistician. A total of 500 patients from 75 GP practices will be
% recruited into the trial.


\subsection{Trial start and end dates}

Trial recruitment start and end dates and the follow-up period

% Recruitment started in October 2017 and is due to finish in October
% 2020. The follow-up period will run for 12 months until October
% 2021.

\section{Economic approach/overview}

\subsection{Aim(s) of economic evaluation}

Describe the aim(s) of the economic evaluation

% The aim of the economic evaluation is to address the question “What
% is the cost-effectiveness of continuous subcutaneous insulin
% injections (CSII) compared with multiple daily injections (MDI) in
% patients with type 1 diabetes receiving a structured education
% programme?”.

\subsection{Objective(s) of economic evaluation}

Describe the objectives (primary and secondary) of the economic evaluation

% The primary objective of the health economic evaluation is to
% estimate the long-term cost-effectiveness of continuous subcutaneous
% insulin injections (CSII) versus multiple daily injections (MDI) for
% patients receiving a structured education programme over a life time
% horizon using economic modelling techniques. A secondary objective
% is to calculate the short-term cost-effectiveness of CSII versus MDI
% in the first 2 years after patients receive the education programme
% in a within-trial economic evaluation.

\subsection{Overview of economic analysis}

Briefly outline and justify the type of economic evaluation to be
undertaken, identifying the primary economic analysis and outlining
the analysis plan and the methods that will be used

% The within-trial economic analysis will be performed using
% individual patient level data from the [trial name]. The analytical
% approaches will take the form of cost-effectiveness and cost-utility
% analysis. Based on trial evidence, incremental cost-effectiveness
% (and cost-utility) ratios will be calculated by taking a ratio of
% the difference in the mean costs and mean effects (or utility
% measure).

\subsection{Jurisdiction(s)}

Specify the jurisdiction(s) in which the analysis will be conducted
including details of the country(s) and health system(s)

% The trial is conducted in the UK which has a national health service
% (NHS), providing publicly funded healthcare, primarily free of
% charge at the point of use.


\subsection{Perspective(s)}

State the perspective(s) from which the economic analysis is being
conducted, such as societal perspective and/or healthcare payer
perspective

% The primary economic analysis will be from the NHS and personal
% social services (PSS) perspective. A secondary analysis will include
% the perspective of patients and carers.


\subsection{Time horizon(s)}

State the time horizon(s) over which costs and consequences are being evaluated

% The primary economic analysis will compare the costs and
% consequences of each arm over the first 26 weeks after
% randomisation. A secondary analysis will extend this to compare
% costs and benefits over the two -year follow-up period from
% randomisation.


\section{Economic data collection \& management}

\subsection{Statistical software}

Specify the statistical software that will be used to carry out the
health economic analysis

% Stata version x.x or higher will be used for exploratory analysis
% and Stata and/or MLWin for the main statistical analysis involving
% multilevel multivariable regression.


\subsection{Identification of resources}

Justify and describe items of resource use that will be measured as
part of the trial

% The following items of health care resource use that may differ
% between arms will be measured: health service resource use,
% productivity losses, personal expenditure on health care.  In
% addition staff training and delivery of the intervention will be
% measured to assess the cost of the intervention.


\subsection{Measurement of resource-use data}

Describe the resource-use data collection method(s) (including
external routine datasets) and the time points at which they will be
used.

% Resource-use data will be collected until 18 months post
% randomisation using trial case report forms (CRFs), completed by the
% trial nurses. Patient questionnaires (either postal or online) at 6
% and 12 months follow up will be used to collect information on other
% hospital use and community care use.

\subsection{Valuation of resource-use data}

For each resource item measured, describe how the unit cost will be
derived and from which specific price year. Outline how adjustments
will be made for sources from different price years and which
inflation index will be used.

% All resource use will be valued in monetary terms using appropriate
% UK unit costs or participant valuations estimated at the time of
% analysis (2019-2020). Adjustments will be made for inflation using
% the ONS GDP deflator index.  NHS reference costs will be employed to
% value hospital resource use (e.g. A&E visits and outpatient
% attendances). Medication costs will be taken from the British
% National Formulary (BNF) and the Prescription Cost Analysis (PCA)
% for England.

\subsection{Identification of outcome(s)}

Specify and justify the outcome(s) that will be measured

% The primary economic outcome measure will be Quality-Adjusted Life
% Years (QALYs) derived from utility scores, obtained using the
% EQ-5D-5L quality of life instrument.


\subsection{Measurement of outcome(s)}

Describe the outcome data collection method(s) and the time points at
which they will be used

% Measurements will be recorded prior to randomisation at baseline,
% and at 2 weeks, 6 weeks and 12 weeks post randomisation. Baseline
% and research follow-up assessments will take place at the
% participant's home, general practice or at university premises.

\subsection{Valuation of outcome(s)}

For each outcome measured, describe how it will be valued and the source of these valuations

% Utility scores will be derived from responses to the EQ-5D-5L.  UK
% utility values will be derived using the approach recommended by
% NICE, which is currently using the validated mapping function from
% the existing EQ-5D (-3L). These will be used to form QALYs over the
% 12-week period, adjusting for any imbalances in baseline EQ-5D-5L
% scores.

\subsection{Monitoring collection of health economic data (OPTIONAL)}

Outline how the health economic data collected will be monitored

% Training will be provided to individuals responsible for
% administering the health economics questionnaires. The trial health
% economist(s) will work closely with the trial team throughout the
% data collection period. Data collection forms will be assessed
% throughout the trial period to monitor quality of the data and amend
% any forms or procedures if necessary.


\subsection{Database management (OPTIONAL)}

Outline how the economic data will be stored and managed and by whom

% Economic data will be securely stored on the trial database and
% managed by the trial database manager, [name(s)].


\subsection{Data entry (OPTIONAL)}

Outline how data will be entered/handled and outline any checking systems in place

% All baseline data will be entered into the case report form (CRF) by
% the trial research nurses at the recruitment site. Follow-up data
% collected from postal questionnaires will be entered by the central
% research team.  The database will use controls to limit data entry
% to plausible values.


\subsection{Data archiving (OPTIONAL)}

State whether datasets, interim datasets and final analysis will be archived, and if so, how

% A copy of health economic analysis files, derived datasets, interim
% datasets and final analysis will be locked and archived. Archived
% datasets will be held by [organisation name] and will conform to the
% department data security policy and department data compliance and
% Data Protection Act policies.




\section{Economic data analysis}


\subsection{Analysis population}

Outline the analysis population that will be used in the economic
base-case analysis (such as intention to treat, per protocol)

% The full analysis set will include all randomised participants,
% which is in accordance with the “intention to treat” (ITT)
% principle. A per protocol set will include all participants in the
% full analysis set who are deemed to have no major protocol
% violations (e.g. patient not receiving any of the intended
% intervention).


\subsection{Timing of analyses}

Describe the timing of all planned analyses (e.g. interim and final
analyses)

% The primary (“final”) analysis will be conducted once all patients
% have been followed for two years after the first dose of [trial
% drug], although an interim analysis will be conducted on year 1 data
% once all patients have been followed for one year. The interim
% analysis will take a one-year time horizon and use only data
% collected in patients’ first year of follow-up, with no
% extrapolation. The final analysis will include a within-trial
% analysis, taking a two-year time horizon and extrapolating beyond
% the end of the trial.

\subsection{Discount rates for costs and benefits}

Detail the source of, and justification for, discount rates used for
costs and benefits

% Costs and benefits will be discounted at 3.5\% p.a. as recommended by NICE.


\subsection{Cost-effectiveness threshold(s)}

Detail the cost-effectiveness threshold(s) to be used in
analysis/interpretation

% The estimated mean QALYs and costs associated with each treatment
% option will be combined with a feasible range of values for decision
% makers’ willingness-to-pay (ʎ), to obtain the distribution of net
% benefits at different levels of ʎ. The primary economic analysis
% will use a cost-effectiveness threshold of £20,000 per QALY.

\subsection{Statistical decision rule(s)}

Describe how inference will be drawn (e.g. significance level,
confidence intervals or mean net benefit)

% Mean differences in costs, QALYs and net benefits between the
% treatment groups will be estimated with associated
% 95% confidence intervals.


\subsection{Analysis of resource use}

Describe how differences in the use of resources/services between
randomised groups will be compared

% Differences in the use of services between randomised groups will be
% described but not compared statistically.

\subsection{Analysis of costs}

Describe analyses of the cost data, specifying any covariates for
statistical adjustment, assumptions, and alternative methods

% Differences in overall mean costs between the arms will be analysed
% initially using Ordinary Least Squares (OLS) regression adjusting
% for the minimisation variables of the randomisation procedure. The
% distribution of residuals from the regression model will then be
% examined and a decision will be made as to whether OLS is
% appropriate or another type of regression model should be considered
% (e.g. Generalised Linear Models (GLM)).


\subsection{Analysis of outcomes}

For each outcome used in the economic analysis, describe how the
outcome will be analysed, specifying any covariates for statistical
adjustment, assumptions, and alternative methods.

% An appropriate regression model will be used to adjust for any
% imbalance in baseline utility and the minimisation variables of the
% randomisation process.


\subsection{Data cleaning for analysis}

Outline how data will be cleaned before analysis

% Face validity tests will be conducted on data (e.g. to identify
% misspelt text) and checked against the source documents. Corrections
% made will be documented in the Stata code.

\subsection{Missing data}

Specify the procedure for dealing with missing data

% Trial data will be examined for any missing data. The appropriate
% method for dealing with missing data will depend on the proportion
% of missing data and likely mechanism of missingness. For example,
% multiple imputation methods may be used if the data is missing at
% random (MAR).


\subsection{Analysis of cost-effectiveness}

Describe the methods that will be used to summarise
cost-effectiveness.

% Cost and QALY data will be combined to calculate an incremental
% cost-effectiveness ratio (ICER) and net monetary benefit (NMB)
% statistic from the NHS and PSS perspective. Seemingly Unrelated
% Regression (SUR) will be used, if appropriate, to account for the
% correlation between the costs and the QALYS.


\subsection{Sampling uncertainty}

Describe how uncertainty around the costs and effectiveness estimates
and summary cost-effectiveness measures will be explored

% The nonparametric bootstrapping approach will be used to determine the
% level of sampling uncertainty surrounding the mean ICER by generating
% 10,000 estimates of incremental costs and benefits.


\subsection{Subgroup analyses or analysis of heterogeneity}

Describe any analyses of subgroups or heterogeneity in cost-effectiveness and the analysis methods used

% Analyses will also be conducted on the final dataset to investigate
% how cost-effectiveness varies between different patient subgroups
% (e.g. age <60/60+; sex). Any subgroup analyses for which the smaller
% subgroup includes fewer than 50 participants will be omitted.


\subsection{Sensitivity analyses}

Describe any sensitivity analyses and their form

% Several sensitivity analyses will be undertaken to explore
% uncertainties surrounding key parameters in the economic
% evaluation. The results for complete cost and quality of life data
% (i.e. those with no missing data) as well as a strict per-protocol
% analysis of the data will be provided to identify the impact of
% missing data on the analysis and any sensitivity to protocol
% violations.

\section{Modelling}

\subsection{Extrapolation or decision analytic modelling}

Outline whether decision analytic modelling or any other extrapolation
will be used to estimate cost-effectiveness results beyond the period
of the trial or to introduce an additional comparator or other
evidence.

% Decision analytic modelling will be undertaken (e.g. to extrapolate
% costs & outcomes beyond the follow up period of trial), irrespective
% of statistical significance in trial results, if there is potential
% for the cost -effectiveness of active interventions to improve under
% a longer analysis time horizon than the 18 months follow-up and /or
% under a more efficient risk screening process.


\subsection{Model type}

Describe the modelling approach that will be used and duration of
extrapolation

% A long-term Markov decision model with annual cycle will be used to
% evaluate effects of intervention on costs, health gains and
% cost-effectiveness over the patient’s lifetime.

\subsection{Model structure}

Detail the model structure (where possible, include diagram of model states and transitions between them)

% The decision model will comprise three arms, with one arm for each
% intervention evaluated. Each arm will be structured as a Markov
% model built around health states to which health care cost and
% health related quality of life (HRQoL) data collected as part of the
% trial will be linked. The model structure is shown in Figure X.


\subsection{Treatment effect beyond the end of the trial}

Describe the duration and size of treatment effect in the period
beyond the end of the trial

% The hazard ratio for disease specific mortality observed during the
% trial will be assumed to persist after the end of trial follow up.

\subsection{Other key assumptions}

List the key structural assumptions of the model

% The main structural assumptions underpinning the decision model are
% listed below [list those that are relevant to specific
% disease/trial]. The model structure maybe subject to change,
% following initial exploratory analysis of trial data.

\subsection{Methods for identifying and estimating parameters}

For each model parameter, describe the methods and data sources that
will be used to estimate the parameter (e.g. from the RCT, systematic
review, meta-analysis, other published data or expert opinion)

% The model will require 4 main sets of parameters, which are expected
% to be mainly derived from the trial data. 1) Transition
% probabilities between health states, 2) Treatment Effect/s of the
% intervention, 3) Quality of life decrements, 4) Health care
% costs. Transition probabilities between health states will be
% estimated by sex and 5 or 10-year age groups using trial
% data. Quality of life decrements and costs associated with a fall or
% fracture will be derived from patient questionnaires, analysed using
% regression analysis and routine hospital admissions data.  Other
% parameters, for example related to ‘natural history of disease’,
% will be parameterised using published data, and where necessary
% using formally elicited expert opinion.

\subsection{Model uncertainty}

Describe the methods that will be used to assess parameter uncertainty
in the results. Describe sensitivity analyses for the impact of other
types of uncertainty on results.

% Parameter uncertainty will be assessed using probabilistic
% sensitivity analysis (i.e. by fitting a probability distribution to
% each uncertain parameter) and running Monte Carlo simulations


\subsection{Model validation}

Describe the methods and data that will be used to check the face,
internal and external validity of the model

% The model will be estimated and internally validated using trial
% data.

\subsection{Subgroup analyses/heterogeneity}

Describe subgroup or heterogeneity analyses that will be executed and
reported within the extrapolation or decision analytic modelling

% The model will be used to evaluate the cost-effectiveness of the
% intervention in categories of trial participants by age (50-59;
% 60-69; 70+) and estimated 5-year vascular disease risk
% (<10%; ≥10,<20%; ≥20%).


\subsection{Value of information analysis (OPTIONAL)}

Describe whether value of information analysis is planned and the type
and methods that will be used to calculate value of information

% As part of the analysis we will conduct a value of information
% analysis (VOI). Expected value of perfect information (EVPI) will be
% used to indicate whether the research is potentially worthwhile. In
% addition, the expected value of perfect information for parameters
% (EVPPI) will also be calculated to identify those parameters for
% which more precise estimates would be most valuable.



\section{Reporting/publishing}

\subsection{Reporting standards}

Describe any guidelines that will be followed when publishing results

% CHEERS guidelines will be followed when reporting the health
% economic evaluation, in a format appropriate to stakeholders and
% policy makers.

\subsection{Deviations from the HEAP}

Describe the procedure for reporting any deviations from the HEAP

% Any deviation from HEAP will be described and justified in the final
% published report.

\section{Appendices}


\subsection{Health economic collection tools}

Include template examples of the resource-use data collection sheets
and resource-use questionnaires

% Data collection sheets on hospital stays, visits to A&E, and home
% visits are given in Appendix X and include health utility
% measures. The resource-use questionnaire has been deposited in DIRUM
% (http://www.dirum.org/).

\subsection{Cross-referencing to other trial documents (OPTIONAL)}

Reference to other relevant trial documents that are adhered to and
followed when writing the HEAP and any other references used when
writing the HEAP

% The [name of trials unit] Standard Operating Procedure for Economic
% Evaluations (version 2.1) was followed in designing this analysis.
% The analysis described in this plan adheres to the [organisation
% name] Data Management Plan (version 1.1).


\subsection{Illustrations (OPTIONAL)}

Illustrations such as annotated questionnaires detailing the database
fieldnames, flow charts outlining the flow of data for the economic
evaluation, or template tables

% The conduct and procedures for the economic evaluation will be fully
% integrated into the [name] trial from planning and designing the
% economic evaluation through to publication. The following flowchart
% should be applied.


"""

spirit = r"""

Nella compilazione delle parti di propria competenza si consiglia di
fare riferimento al documento
\href{https://www.ncbi.nlm.nih.gov/pmc/articles/pmid/23303884/}{SPIRIT
  2013 explanation and elaboration}.


\section{Protocol}

% --------------------------------------------------------------
\subsection{Administrative information}

\subsubsection{Title}

Item 1: Descriptive title identifying the study design, population,
interventions, and, if applicable, trial acronym

\subsubsection{Trial registration}

\begin{itemize}
\item Item 2a: Trial identifier and registry name. If not yet registered, name
  of intended registry
\item Item 2b: All items from the World Health Organization Trial Registration
  Data Set
\end{itemize}

\subsubsection{Protocol version}

Item 3: Date and version identifier

\subsubsection{Funding}

Item 4: Sources and types of financial, material, and other support

\subsubsection{Roles and responsibilities}

\begin{itemize}
\item Item 5a: Names, affiliations, and roles of protocol contributors
\item Item 5b:   Name and contact information for the trial sponsor
\item Item 5c: Role of study sponsor and funders, if any, in study design;
  collection, management, analysis, and interpretation of data;
  writing of the report; and the decision to submit the report for
  publication, including whether they will have ultimate authority
  over any of these activities
\item Item 5d: Composition, roles, and responsibilities of the coordinating
  centre, steering committee, endpoint adjudication committee, data
  management team, and other individuals or groups overseeing the
  trial, if applicable (see Item 21a for data monitoring committee)
\end{itemize}


% --------------------------------------------------------------
\subsection{Introduction}

\subsubsection{Background and rationale}

\begin{itemize}
\item Item 6a:  Description of research question and justification for
  undertaking the trial, including summary of relevant studies
  (published and unpublished) examining benefits and harms for each
  intervention
\item Item 6b: Explanation for choice of comparators
\end{itemize}


\subsubsection{Objectives}

Item 7: Specific objectives or hypotheses

\subsubsection{Trial design}

Item 8: Description of trial design including type of trial (eg, parallel
group, crossover, factorial, single group), allocation ratio, and
framework (eg, superiority, equivalence, noninferiority, exploratory)

% ------------------------------------------------------------------
\subsection{Methods: Participants, interventions, and outcomes}

\subsubsection{Study setting}

Item 9: Description of study settings (eg, community clinic, academic
hospital) and list of countries where data will be
collected. Reference to where list of study sites can be obtained

\subsubsection{Eligibility criteria}

Item 10: Inclusion and exclusion criteria for participants. If applicable,
eligibility criteria for study centres and individuals who will
perform the interventions (eg, surgeons, psychotherapists)


\subsubsection{Interventions}

\begin{itemize}
\item Item 11a: Interventions for each group with sufficient detail to allow
  replication, including how and when they will be administered
\item Item 11b: Criteria for discontinuing or modifying allocated interventions
  for a given trial participant (eg, drug dose change in response to
  harms, participant request, or improving/worsening disease)
\item Item 11c: Strategies to improve adherence to intervention protocols, and
  any procedures for monitoring adherence (eg, drug tablet return,
  laboratory tests)
\item Item 11d: Relevant concomitant care and interventions that are permitted
  or prohibited during the trial
\end{itemize}

\subsubsection{Outcomes}

Item 12: Primary, secondary, and other outcomes, including the specific
measurement variable (eg, systolic blood pressure), analysis metric
(eg, change from baseline, final value, time to event), method of
aggregation (eg, median, proportion), and time point for each
outcome. Explanation of the clinical relevance of chosen efficacy and
harm outcomes is strongly recommended

\subsubsection{Participant timeline}

Item 13: Time schedule of enrolment, interventions (including any run-ins and
washouts), assessments, and visits for participants. A schematic
diagram is highly recommended (see Figure)

\subsubsection{Sample size}

Item 14: Estimated number of participants needed to achieve study objectives
and how it was determined, including clinical and statistical
assumptions supporting any sample size calculations

\subsubsection{Recruitment}

Item 15: Strategies for achieving adequate participant enrolment to reach
target sample size

% -----------------------------------------------------------------------
\subsection{Methods: Assignment of interventions (for controlled trials)}

\subsubsection{Allocation sequence generation}

Item 16a: Method of generating the allocation sequence (eg, computer-generated
random numbers), and list of any factors for stratification. \\
To reduce predictability of a random sequence, details of any planned
restriction (eg, blocking) should be provided in a separate document
that is unavailable to those who enrol participants or assign
interventions

\subsubsection{Allocation concealment mechanism}

Item 16b: Mechanism of implementing the allocation sequence (eg, central
telephone; sequentially numbered, opaque, sealed envelopes),
describing any steps to conceal the sequence until interventions are
assigned

\subsubsection{Allocation implementation}

Item 16c: Who will generate the allocation sequence, who will enrol
participants, and who will assign participants to interventions

\subsubsection{Blinding (masking)}

\begin{itemize}
\item Item 17a: Who will be blinded after assignment to interventions
  (eg, trial participants, care providers, outcome assessors, data
  analysts), and how
\item Item 17b: If blinded, circumstances under which unblinding is
  permissible, and procedure for revealing a participant’s allocated
  intervention during the trial
\end{itemize}


% -----------------------------------------------------------------------
\subsection{Methods: Data collection, management, and analysis}

\subsubsection{Data collection methods}

\begin{itemize}
\item Item 18a: Plans for assessment and collection of outcome,
  baseline, and other trial data, including any related processes to
  promote data quality (eg, duplicate measurements, training of
  assessors) and a description of study instruments (eg,
  questionnaires, laboratory tests) along with their reliability and
  validity, if known. Reference to where data collection forms can be
  found, if not in the protocol
\item Item 18b: Plans to promote participant retention and complete
  follow-up, including list of any outcome data to be collected for
  participants who discontinue or deviate from intervention protocols
\end{itemize}


\subsubsection{Data management}

Item 19: Plans for data entry, coding, security, and storage, including any
related processes to promote data quality (eg, double data entry;
range checks for data values). Reference to where details of data
management procedures can be found, if not in the protocol


\subsubsection{Statistical methods}
\begin{itemize}
\item Item 20a: Statistical methods for analysing primary and secondary
  outcomes. Reference to where other details of the statistical
  analysis plan can be found, if not in the protocol
\item Item 20b: Methods for any additional analyses (eg, subgroup and adjusted
  analyses)
\item Item 20c: Definition of analysis population relating to protocol
  non-adherence (eg, as randomised analysis), and any statistical
  methods to handle missing data (eg, multiple imputation)
\end{itemize}

% -----------------------------------------------------------------------
\subsection{Methods: Monitoring}

\subsubsection{Data monitoring}

\begin{itemize}
\item Item 21a: Composition of data monitoring committee (DMC); summary of its
  role and reporting structure; statement of whether it is independent
  from the sponsor and competing interests; and reference to where
  further details about its charter can be found, if not in the
  protocol. Alternatively, an explanation of why a DMC is not needed
\item Item 21b: Description of any interim analyses and stopping guidelines,
  including who will have access to these interim results and make the
  final decision to terminate the trial
\end{itemize}

\subsubsection{Harms}

Item 22: Plans for collecting, assessing, reporting, and managing
solicited and spontaneously reported adverse events and other
unintended effects of trial interventions or trial conduct


\subsubsection{Auditing}
Item 23: Frequency and procedures for auditing trial conduct, if any,
and whether the process will be independent from investigators and the
sponsor


% -----------------------------------------------------------------------
\subsection{Ethics and dissemination}

\subsubsection{Research ethics approval}

Item 24: Plans for seeking research ethics committee/institutional
review board (REC/IRB) approval

\subsubsection{Protocol amendments}

Item 25: Plans for communicating important protocol modifications (eg,
changes to eligibility criteria, outcomes, analyses) to relevant
parties (eg, investigators, REC/IRBs, trial participants, trial
registries, journals, regulators)

\subsubsection{Consent or assent}

\begin{itemize}
\item Item 26a: Who will obtain informed consent or assent from
  potential trial participants or authorised surrogates, and how (see
  Item 32)
\item Item 26b: Additional consent provisions for collection and use of
  participant data and biological specimens in ancillary studies, if
  applicable
\end{itemize}

\subsubsection{Confidentiality}

Item 27: How personal information about potential and enrolled participants
will be collected, shared, and maintained in order to protect
confidentiality before, during, and after the trial

\subsubsection{Declaration of interests}

Item 28: Financial and other competing interests for principal investigators
for the overall trial and each study site

\subsubsection{Access to data}

Item 29: Statement of who will have access to the final trial dataset, and
disclosure of contractual agreements that limit such access for
investigators

\subsubsection{Ancillary and post-trial care}

Item 30: Provisions, if any, for ancillary and post-trial care, and for
compensation to those who suffer harm from trial participation

\subsubsection{Dissemination policy}

\begin{itemize}
\item Item 31a: Plans for investigators and sponsor to communicate
  trial results to participants, healthcare professionals, the public,
  and other relevant groups (eg, via publication, reporting in results
  databases, or other data sharing arrangements), including any
  publication restrictions
\item Item 31b: Authorship eligibility guidelines and any intended use of
  professional writers
\item Item 31c: Plans, if any, for granting public access to the full
  protocol, participant-level dataset, and statistical code
\end{itemize}
% -----------------------------------------------------------------------
\subsection{Appendices}


\subsubsection{Informed consent materials}

Item 32: Model consent form and other related documentation given to
participants and authorised surrogates

\subsubsection{Biological specimens}

Item 33: Plans for collection, laboratory evaluation, and storage of
biological specimens for genetic or molecular analysis in the current
trial and for future use in ancillary studies, if applicable


"""

trials = r"""
% STARTHERE

Template utilizzato da Trials, disponibile
\href{https://trialsjournal.biomedcentral.com/submission-guidelines/preparing-your-manuscript/study-protocol/structured-study-protocol-template}{qui},
che riorganizza gli item dello
\href{http://www.equator-network.org/reporting-guidelines/spirit-2013-statement-defining-standard-protocol-items-for-clinical-trials}{SPIRIT}
per rendere il tutto più completo/scorrevole.  Le indicazioni in
italico sono divise in Trials guidance (fonte: detto giornale ed
obbligatorie per esso) o Spirit guidance (fonte SPIRIT: meglio
considerarle per qualsiasi journal): tutto il testo in italico si può
cancellare dopo aver compilato. Se un item non si applica fornire una
spiegazione, non cancellarlo dal template.  I numeri tra graffe
indicano gli item di SPIRIT sono da lasciare.

Nella compilazione delle parti di propria competenza si consiglia di
fare riferimento al documento
\href{https://www.ncbi.nlm.nih.gov/pmc/articles/pmid/23303884/}{SPIRIT
  2013 explanation and elaboration}.


\section{Title}

{\em SPIRIT guidance: Descriptive title identifying the study design,
population, interventions, and, if applicable, trial acronym.}

\section{Protocol contributors}

{\em Trials guidance: Names of protocol contributors.}

\section{Abstract}

{\em Trials guidance: The Abstract should not exceed 350 words. Please
minimize the use of abbreviations and do not cite references in the
abstract. The abstract must include the following separate sections:
\begin{itemize}
\item
  \textbf{Background}: the context and purpose of the study
\item
  \textbf{Methods}: how the study will be performed
\item
  \textbf{Discussion}: a brief summary and potential implications
\item \textbf{Trial registration}: If your article reports the results
  of a health care intervention on human participants, it must be
  registered in an appropriate registry and the registration number
  and date of registration should be in stated in this section. If it
  was not registered prospectively (before enrollment of the first
  participant), you should include the words 'retrospectively
  registered'. See our editorial policies for more information on
  trial registration.
\end{itemize}}

\section{Keywords}

{\em Trials guidance: Three to ten keywords representing the main
content of the article.}

\section{Administrative information}

{\em Trials guidance: please include this text in your protocol just
above the Administrative information table:}

Note: the numbers in curly brackets in this protocol refer to SPIRIT
checklist item numbers. The order of the items has been modified to
group similar items (see
\url{http://www.equator-network.org/reporting-guidelines/spirit-2013-statement-defining-standard-protocol-items-for-clinical-trials/}).


\begin{table}
  \centering
  \begin{tabular}{|l|l|}
    \hline
    Title \{1\} &
                  {\em SPIRIT guidance: Descriptive title identifying
                  the study design, population, interventions, and, if
                  applicable, trial acronym. }\\
    \hline
    Trial registration \{2a and 2b\}
                &
                  {\em SPIRIT guidance: Trial identifier and registry name.
                  If not yet registered, name of intended registry.

                  Item 2b is met if the register used for registration
                  collects all items from the World Health Organization
                  Trial Registration Data Set.}\\
    \hline
    Protocol version \{3\}
                &
                  {\em SPIRIT guidance: Date and version identifier.}\\
    \hline
    Funding \{4\}
                &
                  {\em  SPIRIT guidance: Sources and types of financial,
                  material, and other support.}\\
    \hline
    Author details \{5a\}
                &
                  {\em SPIRIT guidance: Affiliations of protocol
                  contributors.}\\
    \hline
    Name and contact information for the trial sponsor \{5b\}
                &
                  {\em SPIRIT guidance: Name and contact information for
                  the trial sponsor.}\\                  
    \hline
    Role of sponsor \{5c\}
                & {\em
                  SPIRIT guidance: Role of study sponsor and
                  funders, if any, in study design; collection,
                  management, analysis, and
                  interpretation of data; writing of the report;
                  and the decision to
                  submit the report for publication, including whether they
                  will have ultimate authority over any of these activities.}\\
    \hline
  \end{tabular}
\end{table}



\section{Introduction}

\subsection{Background and rationale \{6a\}}

{\em
SPIRIT guidance: Description of research question and justification for
undertaking the trial, including summary of relevant studies (published
and unpublished) examining benefits and harms for each intervention.
}

\subsection{Objectives \{7\}}

{\em
SPIRIT guidance: Specific objectives or hypotheses.
}

\subsection{Trial design \{8\}}

{\em
SPIRIT guidance: Description of trial design including type of trial
(eg, parallel group, crossover, factorial, single group), allocation
ratio, and framework (eg, superiority, equivalence, noninferiority,
exploratory).
}
\section{Methods: Participants, interventions and outcomes}

\subsection{Study setting \{9\}}

{\em
SPIRIT guidance: Description of study settings (eg, community clinic,
academic hospital) and list of countries where data will be collected.
Reference to where list of study sites can be obtained.
}

\subsection{Eligibility criteria \{10\}}

{\em
SPIRIT guidance: Inclusion and exclusion criteria for participants. If
applicable, eligibility criteria for study centres and individuals who
will perform the interventions (eg, surgeons, psychotherapists).
}

\subsection{Who will take informed consent? \{26a\}}

{\em
SPIRIT guidance: Who will obtain informed consent or assent from
potential trial participants or authorised surrogates, and how (see Item
32).
}

\subsection{Additional consent provisions for collection and use of
  participant data and biological specimens \{26b\}}

{\em
SPIRIT guidance: Additional consent provisions for collection and use of
participant data and biological specimens in ancillary studies, if
applicable.
}

\section{Interventions}

\subsection{Explanation for the choice of comparators \{6b\}}

{\em
SPIRIT guidance: Explanation for choice of comparators.
}

\subsection{Intervention description \{11a\}}

{\em
SPIRIT guidance: Interventions for each group with sufficient detail to
allow replication, including how and when they will be administered.
}

\subsection{Criteria for discontinuing or modifying allocated
  interventions \{11b\}}

{\em
SPIRIT guidance: Criteria for discontinuing or modifying allocated
interventions for a given trial participant (eg, drug dose change in
response to harms, participant request, or improving/worsening disease).
}

\subsection{Strategies to improve adherence to interventions \{11c\}}

{\em
SPIRIT guidance: Strategies to improve adherence to intervention
protocols, and any procedures for monitoring adherence (eg, drug tablet
return, laboratory tests).
}

\subsection{Relevant concomitant care permitted or prohibited during the
trial \{11d\}}

{\em
SPIRIT guidance: Relevant concomitant care and interventions that are
permitted or prohibited during the trial.
}

\subsection{Provisions for post-trial care \{30\}}

{\em
SPIRIT guidance: Provisions, if any, for ancillary and post-trial care,
and for compensation to those who suffer harm from trial participation.
}

\subsection{Outcomes \{12\}}

{\em
SPIRIT guidance: Primary, secondary, and other outcomes, including the
specific measurement variable (eg, systolic blood pressure), analysis
metric (eg, change from baseline, final value, time to event), method of
aggregation (eg, median, proportion), and time point for each outcome.
Explanation of the clinical relevance of chosen efficacy and harm
outcomes is strongly recommended.
}

\subsection{Participant timeline \{13\}}

{\em
SPIRIT guidance: Time schedule of enrolment, interventions (including
any run-ins and washouts), assessments, and visits for participants. A
schematic diagram is highly recommended (see figure at
\href{http://www.spirit-statement.org/publications-downloads/}{{http://www.spirit-statement.org/publications-downloads/}}).
}

\subsection{Sample size \{14\}}

{\em
SPIRIT guidance: Estimated number of participants needed to achieve
study objectives and how it was determined, including clinical and
statistical assumptions supporting any sample size calculations.
}

\subsection{Recruitment \{15\}}

{\em
SPIRIT guidance: Strategies for achieving adequate participant enrolment
to reach target sample size.
}

\section{Assignment of interventions: allocation}

\subsection{Sequence generation \{16a\}}

{\em
SPIRIT guidance: Method of generating the allocation sequence (eg,
computer-generated random numbers), and list of any factors for
stratification. To reduce predictability of a random sequence, details
of any planned restriction (eg, blocking) should be provided in a
separate document that is unavailable to those who enrol participants or
assign interventions.
}

\subsection{Concealment mechanism \{16b\}}

{\em
SPIRIT guidance: Mechanism of implementing the allocation sequence (eg,
central telephone; sequentially numbered, opaque, sealed envelopes),
describing any steps to conceal the sequence until interventions are
assigned.
}

\subsection{Implementation \{16c\}}

{\em
SPIRIT guidance: Who will generate the allocation sequence, who will
enrol participants, and who will assign participants to interventions.
}

\section{Assignment of interventions: Blinding}

\subsection{Who will be blinded \{17a\}}

{\em
SPIRIT guidance: Who will be blinded after assignment to interventions
(eg, trial participants, care providers, outcome assessors, data
analysts), and how.
}

\subsection{Procedure for unblinding if needed \{17b\}}

{\em
SPIRIT guidance: If blinded, circumstances under which unblinding is
permissible, and procedure for revealing a participant's allocated
intervention during the trial.
}

\section{Data collection and management}

\subsection{Plans for assessment and collection of outcomes \{18a\}}

{\em
SPIRIT guidance: Plans for assessment and collection of outcome,
baseline, and other trial data, including any related processes to
promote data quality (eg, duplicate measurements, training of assessors)
and a description of study instruments (eg, questionnaires, laboratory
tests) along with their reliability and validity, if known. Reference to
where data collection forms can be found, if not in the protocol.
}

\subsection{Plans to promote participant retention and complete follow-up
\{18b\}}

{\em
SPIRIT guidance: Plans to promote participant retention and complete
follow-up, including list of any outcome data to be collected for
participants who discontinue or deviate from intervention protocols.
}
\subsection{Data management \{19\}}

{\em
SPIRIT guidance: Plans for data entry, coding, security, and storage,
including any related processes to promote data quality (eg, double data
entry; range checks for data values). Reference to where details of data
management procedures can be found, if not in the protocol.
}
\subsection{Confidentiality \{27\}}

{\em
SPIRIT guidance: How personal information about potential and enrolled
participants will be collected, shared, and maintained in order to
protect confidentiality before, during, and after the trial.
}
\subsection{Plans for collection, laboratory evaluation and storage of
biological specimens for genetic or molecular analysis in this
trial/future use \{33\}}

{\em
SPIRIT guidance: Plans for collection, laboratory evaluation, and
storage of biological specimens for genetic or molecular analysis in the
current trial and for future use in ancillary studies, if applicable.
}
\section{Statistical methods}

\subsection{Statistical methods for primary and secondary outcomes \{20a\}}

{\em
SPIRIT guidance: Statistical methods for analysing primary and secondary
outcomes. Reference to where other details of the statistical analysis
plan can be found, if not in the protocol.
}
\subsection{Interim analyses \{21b\}}

{\em
SPIRIT guidance: Description of any interim analyses and stopping
guidelines, including who will have access to these interim results and
make the final decision to terminate the trial.
}
\subsection{Methods for additional analyses (e.g. subgroup analyses)
\{20b\}}

{\em
SPIRIT guidance: Methods for any additional analyses (eg, subgroup and
adjusted analyses).
}

\subsection{Methods in analysis to handle protocol non-adherence and any
statistical methods to handle missing data \{20c\}}

{\em
SPIRIT guidance: Definition of analysis population relating to protocol
non-adherence (eg, as randomised analysis), and any statistical methods
to handle missing data (eg, multiple imputation).
}

\subsection{Plans to give access to the full protocol, participant
level-data and statistical code \{31c\}}

{\em
SPIRIT guidance: Plans, if any, for granting public access to the full
protocol, participant-level dataset, and statistical code.
}

\section{Oversight and monitoring}

\subsection{Composition of the coordinating centre and trial steering
committee \{5d\}}

{\em
Trials guidance: Provide information on the composition, roles and
responsibilities of the coordinating centre and trial steering committee
and all groups providing day to day support for the trial. There will
always be a group running the trial day-to-day and providing
organisational support and knowing how often they will meet, plus
information on other committees providing oversight such as a Trial
Steering Committee, and how often they will meet over the course of the
trial, is what we need for item 5d. We do not need names of staff.

SPIRIT guidance: Composition, roles, and responsibilities of the
coordinating centre, steering committee, endpoint adjudication
committee, data management team, and other individuals or groups
overseeing the trial, if applicable (see Item 21a for data monitoring
committee).
}

\subsection{Composition of the data monitoring committee, its role and
reporting structure \{21a\}}

{\em
SPIRIT guidance: Composition of data monitoring committee (DMC); summary
of its role and reporting structure; statement of whether it is
independent from the sponsor and competing interests; and reference to
where further details about its charter can be found, if not in the
protocol. Alternatively, an explanation of why a DMC is not needed.
}

\subsection{Adverse event reporting and harms \{22\}}

{\em
SPIRIT guidance: Plans for collecting, assessing, reporting, and
managing solicited and spontaneously reported adverse events and other
unintended effects of trial interventions or trial conduct.
}

\subsection{Frequency and plans for auditing trial conduct \{23\}}

{\em
SPIRIT guidance: Frequency and procedures for auditing trial conduct, if
any, and whether the process will be independent from investigators and
the sponsor.
}

\subsection{Plans for communicating important protocol amendments to
relevant parties (e.g. trial participants, ethical committees) \{25\}}

{\em
SPIRIT guidance: Plans for communicating important protocol
modifications (eg, changes to eligibility criteria, outcomes, analyses)
to relevant parties (eg, investigators, REC/IRBs, trial participants,
trial registries, journals, regulators).
}

\section{Dissemination plans \{31a\}}

{\em SPIRIT guidance: Plans for investigators and sponsor to
  communicate trial results to participants, healthcare professionals,
  the public, and other relevant groups (eg, via publication,
  reporting in results databases, or other data sharing arrangements),
  including any publication restrictions.}

\section{Discussion}

{\em Trials guidance: This should include a discussion of any
  practical or operational issues involved in performing the study and
  any issues not covered in other sections.}

\section{Trial status}

{\em Trials guidance: Authors should report the protocol version
number and date, the date recruitment began, and the approximate date
when recruitment will be completed.}

\section{Abbreviations}

{\em Trials guidance: If abbreviations are used in the text they
should be defined in the text at first use, and a list of abbreviations
should be provided.}

\section{Declarations}

{\em
Trials guidance: All manuscripts must contain the following
subheadings:
\begin{itemize}
\item Acknowledgements
\item Authors' contributions
\item Funding
\item Availability of data and material
\item Ethics approval and consent to participate
\item Consent for publication
\item Competing interests
\item Authors' information (optional)
\end{itemize}
}

\subsection{Acknowledgements}

{\em

\emph{Trials} guidance: Please acknowledge anyone who contributed
towards the article who does not meet the criteria for authorship
including anyone who provided professional writing services or
materials. Authors should obtain permission to acknowledge from all
those mentioned in the Acknowledgements section. See
our \href{http://www.biomedcentral.com/submissions/editorial-policies\#authorship}{editorial
policies} for a full explanation of acknowledgements and authorship
criteria. If you do not have anyone to acknowledge, please write ``Not
applicable'' in this section. 

Group authorship (for manuscripts involving a collaboration group): if
you would like the names of the individual members of a collaboration
Group to be searchable through their individual PubMed records, please
ensure that the title of the collaboration Group is included on the
title page and in the submission system and also include collaborating
author names as the last paragraph of the ``Acknowledgements'' section.
Please add authors in the format First Name, Middle initial(s)
(optional), Last Name. You can add institution or country information
for each author if you wish, but this should be consistent across all
authors. Please note that individual names may not be present in the
PubMed record at the time a published article is initially included in
PubMed as it takes PubMed additional time to code this information.
}

\subsection{Authors' contributions \{31b\}}

{\em SPIRIT guidance: Authorship eligibility guidelines and any
  intended use of professional writers.

Trials guidance: The individual contributions of authors to the
manuscript should be specified in this section. Guidance and criteria
for authorship can be found in
our \href{http://www.biomedcentral.com/submissions/editorial-policies\#authorship}{editorial
policies}. Please use initials to refer to each author's contribution in
this section, for example: ``AB is the Chief Investigator; she conceived
the study, led the proposal and protocol development. CD contributed to
study design and to development of the proposal. EF was the lead trial
methodologist. All authors read and approved the final manuscript.''
}

\subsection{Funding \{4\}}

{\em
SPIRIT guidance: Sources and types of financial, material, and other
support.

Trials guidance: All sources of funding for the research reported
should be declared. You will be required to include a copy of the
original funding document and an English translation of this document as
an additional file on submission, which will be checked against this
declaration. The role of the funding body in the design of the study and
collection, analysis, and interpretation of data and in writing the
manuscript should be declared.
}

\subsection{Availability of data and materials \{29\}}

{\em
SPIRIT guidance: Statement of who will have access to the final trial
dataset, and disclosure of contractual agreements that limit such access
for investigators.

Trials guidance: Please do not include any baseline or pilot data in
your study protocol. The Editorial Office will ask you to remove this
if it is included. Please declare here who will have access to the
final trial dataset and disclose contractual agreements that limit
such access for investigators.
}

\subsection{Ethics approval and consent to participate \{24\}}

{\em
SPIRIT guidance: Plans for seeking research ethics
committee/institutional review board (REC/IRB) approval.

Trials guidance: Trials do not consider study protocols for
studies without ethical approval. You will be required to provide a copy
of the original ethical approval document and an English translation of
this document as an additional file on submission, which will be checked
against this declaration. The name of the ethics committee that approved
the study and the committee's reference number (if applicable) should be
declared. Details of authors' intentions to obtain consent to
participate in the study from participants (or their parent or legal
guardian in the case of children under 16) should be declared. ``eg. ABC
Ethical Review Board ABC123456. Written, informed consent to participate
will be obtained from all participants''
}

\subsection{Consent for publication \{32\}}

{\em
SPIRIT guidance: Model consent form and other related documentation
given to participants and authorised surrogates.

Trials guidance: Please do not include any baseline or pilot data
in your study protocol. The Editorial Office will ask you to remove this
if it is included. If you have included any details, images or videos
relating to an individual person, written informed consent for the
publication of these details must be obtained from that person (or their
parent or legal guardian in the case of children under 18) and declared
in this section. Please also state whether you will be willing to
provide a model consent form on request. If this section does not apply,
please state ``Not applicable''.
}

\subsection{Competing interests \{28\}}

{\em
SPIRIT guidance: Financial and other competing interests for principal
investigators for the overall trial and each study site.

Trials guidance: All financial and non-financial competing
interests must be declared in this section. See
our \href{https://www.biomedcentral.com/getpublished/editorial-policies\#availability+of+data+and+materials}{editorial
policies} for a full explanation of competing interests. If you are
unsure whether you or any of your co-authors have a competing interest
please contact the editorial office. Please use the authors initials to
refer to each authors' competing interests in this section. If you do
not have any competing interests, please state: ``The authors declare
that they have no competing interests'' in this section.
}

\subsection{Authors' information (optional)}

{\em 
Trials guidance: This section is optional.

You may choose to use this section to include any relevant information
about the author(s) that may aid the reader's interpretation of the
article, and understand the standpoint of the author(s). This may
include details about the authors' qualifications, current positions
they hold at institutions or societies, or any other relevant background
information. Please refer to authors using their initials. Note this
section should not be used to describe any competing interests.
}

\section{References}

{\em Seguire il formato richiesto dal giornale dove si vuole pubblicare.}


"""
